==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/providerhub/kotlin/enums/SubscriptionNotificationOperation.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.providerhub.kotlin.enums

import com.pulumi.kotlin.ConvertibleToJava
import kotlin.Suppress

public enum class SubscriptionNotificationOperation(
    public val javaValue: com.pulumi.azurenative.providerhub.enums.SubscriptionNotificationOperation,
) : ConvertibleToJava<com.pulumi.azurenative.providerhub.enums.SubscriptionNotificationOperation> {
    NotDefined(com.pulumi.azurenative.providerhub.enums.SubscriptionNotificationOperation.NotDefined),
    DeleteAllResources(com.pulumi.azurenative.providerhub.enums.SubscriptionNotificationOperation.DeleteAllResources),
    SoftDeleteAllResources(com.pulumi.azurenative.providerhub.enums.SubscriptionNotificationOperation.SoftDeleteAllResources),
    NoOp(com.pulumi.azurenative.providerhub.enums.SubscriptionNotificationOperation.NoOp),
    BillingCancellation(com.pulumi.azurenative.providerhub.enums.SubscriptionNotificationOperation.BillingCancellation),
    UndoSoftDelete(com.pulumi.azurenative.providerhub.enums.SubscriptionNotificationOperation.UndoSoftDelete),
    ;

    override fun toJava(): com.pulumi.azurenative.providerhub.enums.SubscriptionNotificationOperation =
        javaValue

    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.providerhub.enums.SubscriptionNotificationOperation):
            SubscriptionNotificationOperation =
            SubscriptionNotificationOperation.values().first { it.javaValue == javaType }
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/providerhub/kotlin/enums/SubscriptionNotificationOperation.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.providerhub.kotlin.enums

import com.pulumi.kotlin.ConvertibleToJava
import kotlin.Suppress

public enum class SubscriptionNotificationOperation(
    public val javaValue: com.pulumi.azurenative.providerhub.enums.SubscriptionNotificationOperation,
) : ConvertibleToJava<com.pulumi.azurenative.providerhub.enums.SubscriptionNotificationOperation> {
    NotDefined(com.pulumi.azurenative.providerhub.enums.SubscriptionNotificationOperation.NotDefined),
    DeleteAllResources(com.pulumi.azurenative.providerhub.enums.SubscriptionNotificationOperation.DeleteAllResources),
    SoftDeleteAllResources(com.pulumi.azurenative.providerhub.enums.SubscriptionNotificationOperation.SoftDeleteAllResources),
    NoOp(com.pulumi.azurenative.providerhub.enums.SubscriptionNotificationOperation.NoOp),
    BillingCancellation(com.pulumi.azurenative.providerhub.enums.SubscriptionNotificationOperation.BillingCancellation),
    UndoSoftDelete(com.pulumi.azurenative.providerhub.enums.SubscriptionNotificationOperation.UndoSoftDelete),
    ;

    override fun toJava(): com.pulumi.azurenative.providerhub.enums.SubscriptionNotificationOperation = javaValue

    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.providerhub.enums.SubscriptionNotificationOperation): SubscriptionNotificationOperation =
            SubscriptionNotificationOperation.values().first { it.javaValue == javaType }
    }
}
